@@ -2,9 +2,9 @@
 #' @title Constant Absolute Risk Aversion (CARA) Utility Function
 #' @aliases CARA
 #' @description Compute the value and the certainty equivalent of the CARA utility function, i.e. -exp(-gamma*x). In general equilibrium analysis, the CARA utility function has an interval scale like temperature.
-#' @param x a vector of all possible states (e.g. returns).
+#' @param x a payoff k-vector.
 #' @param gamma the Arrow-Pratt measure of absolute risk aversion.
-#' @param p the probability vector. By default, the states are assumed to
+#' @param prob a probability k-vector. By default, the states are assumed to
 #' occur with equal probability.
 #' @return A list containing the following components:
 #' \itemize{
@@ -26,10 +26,8 @@
 #' # two CE calculation methods for random variables of normal distribution
 #' CARA(x, gamma, dnorm(x, mean = mu, sd = sigma))
 #' mu - gamma * sigma^2 / 2
-
-
-CARA <- function(x, gamma, p=rep(1/length(x),length(x))){
-  u <- weighted.mean(-exp(-x * gamma), p)
+CARA <- function(x, gamma, prob = rep(1 / length(x), length(x))) {
+  u <- weighted.mean(-exp(-x * gamma), prob)
   CE <- log(-u) / (-gamma)
-  return(list(u=u, CE=CE))
+  return(list(u = u, CE = CE))
 }
